from django import template
from django.conf import settings
from django.contrib.admin.models import LogEntry

register = template.Library()

@register.simple_tag
def site_name():
    return settings.SITE_NAME if hasattr(settings, 'SITE_NAME') else 'FrontAdmin'

@register.inclusion_tag('elements/logo.html')
def logo(defaut=True):
    return {
        'site_name': settings.SITE_NAME if hasattr(settings, 'SITE_NAME') else 'FrontAdmin',
        'default': defaut
    }

@register.inclusion_tag('elements/sidebar.html')
def sidebar():
    pass

@register.inclusion_tag('elements/warnings_recent_content.html')
def warnings_recent_content():
    entries = LogEntry.objects.all().order_by('-id')[:10]
    return {
        'log_entries': entries
    }


from django.urls import path, include
from frontadmin import views

urlpatterns = [
    path('accounts/', include('django.contrib.auth.urls')),
    path('accounts/profile/', views.profile, name='profile'),
]


#!/usr/bin/env python

from os.path import exists
from setuptools import setup, find_packages

with open("README.rst", "r") as fh:
    long_description = fh.read()

setup(
    name='django-frontadmin',
    version='1.0.6',
    author='Washim Ahmed',
    author_email='washim.ahmed@gmail.com',
    packages=find_packages(),
    scripts=[],
    url='https://github.com/washim/django-frontadmin',
    license='MIT',
    description='Frontadmin is a Django app to conduct Web-based frontend theme.',
    long_description=long_description,
    include_package_data=True,
    install_requires=[
        'django',
    ],
    python_requires='>=3.6',
)